HeadlessThemeProvider class

Provides HeadlessTheme to descendant widgets.

Wrap your app (or a subtree) with this widget to make the theme available via HeadlessThemeProvider.of or HeadlessThemeProvider.themeOf.

Example:

HeadlessThemeProvider(
  theme: MyCustomTheme(),
  child: MaterialApp(...),
)
Inheritance

Constructors

HeadlessThemeProvider({Key? key, required HeadlessTheme theme, required Widget child})
const

Properties

child Widget
The widget below this widget in the tree.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme HeadlessTheme
The theme to provide to descendants.
final

Methods

createElement() InheritedElement
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
updateShouldNotify(covariant HeadlessThemeProvider oldWidget) bool
Whether the framework should notify widgets that inherit from this widget.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

capabilityOf<T>(BuildContext context, {required String componentName}) → T
Convenience method to get a required capability from the theme.
maybeCapabilityOf<T>(BuildContext context, {required String componentName}) → T?
Safe capability lookup.
of(BuildContext context) HeadlessTheme?
Get the HeadlessTheme from the widget tree.
themeOf(BuildContext context) HeadlessTheme
Get the HeadlessTheme from the widget tree.