HeadlessTheme class abstract
Root capability discovery contract (v1 skeleton).
In v1, capabilities are discovered by generic type.
- Implementers
- Annotations
Constructors
- HeadlessTheme()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
capability<
T> () → T? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited